window.Gleam.initSearch([{"doc":"themis","title":"themis","content":"# Themis\n\nPrometheus client in pure Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/themis)](https://hex.pm/packages/themis)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/themis/)\n\n```sh\ngleam add themis\n```\n\n## Quick Start\n\n```gleam\nimport themis\nimport gleam/dict\nimport gleam/io\n\npub fn main() {\n  // Create a new themis store\n  let store = themis.new()\n\n  // Add a gauge metric\n  let assert Ok(store) = themis.add_gauge(\n    store,\n    &quot;process_memory_bytes&quot;,\n    &quot;Current memory usage in bytes&quot;,\n  )\n\n  // Record some values with labels\n  let labels = dict.from_list([\n    #(&quot;process&quot;, &quot;web_server&quot;),\n    #(&quot;instance&quot;, &quot;prod-1&quot;),\n  ])\n  \n  let assert Ok(store) = themis.insert_gauge_record(\n    store,\n    &quot;process_memory_bytes&quot;,\n    labels,\n    metrics.int(1_234_567),\n  )\n\n  // Export metrics in Prometheus format\n  io.println(metrics.print(store))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/themis&gt;.\n\n## Usage\n\n### Working with Different Numeric Types\n\nThemis metric values are set using the dedicated `Number` type. There are 5 number types available:\n\n```gleam\nimport themis\n\n// Integer values\nlet memory = themis.int(1_234_567)\n\n// Decimal (float) values\nlet temperature = themis.dec(23.5)\n\n// Special values\nlet and_beyond = themis.pos_inf()\nlet lower_bound = themis.neg_inf()\nlet unknown = themis.nan()\n```\n\n## Output Format\n\nThe metrics are exported in the standard Prometheus text format:\n\n```\n# # HELP process_memory_bytes Current memory usage in bytes\n# # TYPE process_memory_bytes gauge\nprocess_memory_bytes{process=&quot;web_server&quot;,instance=&quot;prod-1&quot;} 1234567\n```\n\n## License\n\nMIT","url":"index.html"},{"doc":"themis/number","title":"ComparisonError","content":"pub type ComparisonError {\n  NaNValue\n}\n\nNaNValue\n\n\nSynonyms:\nthemis/number.ComparisonError\nthemis/number ComparisonError","url":"themis/number.html#ComparisonError"},{"doc":"themis/number","title":"add","content":"pub fn add(value1 val1: Number, value2 val2: Number) -&gt; Number\n\nSynonyms:\nthemis/number.add\nthemis/number add","url":"themis/number.html#add"},{"doc":"themis/number","title":"compare","content":"pub fn compare(\n  compare val1: Number,\n  to val2: Number,\n) -&gt; Result(Order, ComparisonError)\n Compare two numbers (see gleam_stdlib/order)\n Will return an error if either value is NaN\nSynonyms:\nthemis/number.compare\nthemis/number compare","url":"themis/number.html#compare"},{"doc":"themis/number","title":"dec","content":"pub fn dec(value value: Float) -&gt; Number\n Creates a Number representing a decimal value.\nSynonyms:\nthemis/number.dec\nthemis/number dec","url":"themis/number.html#dec"},{"doc":"themis/number","title":"int","content":"pub fn int(value value: Int) -&gt; Number\n Creates a Number representing an integer value.\nSynonyms:\nthemis/number.int\nthemis/number int","url":"themis/number.html#int"},{"doc":"themis/number","title":"nan","content":"pub fn nan() -&gt; Number\n Creates a Number representing NaN (Not a Number).\nSynonyms:\nthemis/number.nan\nthemis/number nan","url":"themis/number.html#nan"},{"doc":"themis/number","title":"neg_inf","content":"pub fn neg_inf() -&gt; Number\n Creates a Number representing negative infinity.\nSynonyms:\nthemis/number.neg_inf\nthemis/number neg_inf","url":"themis/number.html#neg_inf"},{"doc":"themis/number","title":"pos_inf","content":"pub fn pos_inf() -&gt; Number\n Creates a Number representing positive infinity.\nSynonyms:\nthemis/number.pos_inf\nthemis/number pos_inf","url":"themis/number.html#pos_inf"},{"doc":"themis/number","title":"themis/number","content":"","url":"themis/number.html"},{"doc":"themis","title":"Store","content":"pub type Store {\n  Store(\n    gauges: Dict(metric.MetricName, Metric(Gauge, Number)),\n    counters: Dict(metric.MetricName, Metric(Counter, Number)),\n    histograms: Dict(\n      metric.MetricName,\n      Metric(Histogram, HistogramRecord),\n    ),\n  )\n}\n A Store manages a collection of metrics, ensuring unique metric names.\nStore(\n  gauges: Dict(metric.MetricName, Metric(Gauge, Number)),\n  counters: Dict(metric.MetricName, Metric(Counter, Number)),\n  histograms: Dict(\n    metric.MetricName,\n    Metric(Histogram, HistogramRecord),\n  ),\n)\n\n\nSynonyms:\nthemis.Store\nthemis Store","url":"themis.html#Store"},{"doc":"themis","title":"StoreError","content":"pub type StoreError {\n  MetricNameAlreadyInUse\n  MetricNameNotFound\n  MetricError(metric.MetricError)\n  LabelError(label.LabelError)\n  CounterError(counter.CounterError)\n  HistogramError(histogram.HistogramError)\n}\n Represents possible errors that can occur when operating on the Store.\nMetricNameAlreadyInUse\n Returned when attempting to create a metric with a name that&#39;s already in use\n\nMetricNameNotFound\n Returned when attempting to operate on a metric that doesn&#39;t exist\n\nMetricError(metric.MetricError)\n Wraps errors related to metric name validation\n\nLabelError(label.LabelError)\n Wraps errors related to label validation\n\nCounterError(counter.CounterError)\n Wraps errors related to counters\n\nHistogramError(histogram.HistogramError)\n Wraps errors related to counters\n\nSynonyms:\nthemis.StoreError\nthemis StoreError","url":"themis.html#StoreError"},{"doc":"themis","title":"is_metric_name_used","content":"pub fn is_metric_name_used(\n  store: Store,\n  name: MetricName,\n) -&gt; Bool\n\nSynonyms:\nthemis.is_metric_name_used\nthemis is_metric_name_used","url":"themis.html#is_metric_name_used"},{"doc":"themis","title":"new","content":"pub fn new() -&gt; Store\n Creates a new empty metrics store.\nSynonyms:\nthemis.new\nthemis new","url":"themis.html#new"},{"doc":"themis","title":"print","content":"pub fn print(metrics_store store: Store) -&gt; String\n Formats all metrics in the store as a Prometheus-compatible text string.\n\n ## Examples\n\n \n let metrics_text = print(store)\n // # HELP my_metric My first gauge\n // # TYPE my_metric gauge\n // my_metric{foo=&quot;bar&quot;} 10\n // my_metric{toto=&quot;tata&quot;,wibble=&quot;wobble&quot;} +Inf\n \nSynonyms:\nthemis.print\nthemis print","url":"themis.html#print"},{"doc":"themis","title":"themis","content":"","url":"themis.html"},{"doc":"themis/counter","title":"create_record","content":"pub fn create_record(\n  store store: Store,\n  counter_name name_string: String,\n  labels labels_dict: Dict(String, String),\n) -&gt; Result(Store, StoreError)\n Initializes a new counter metric record with the given labels.\n\n ## Arguments\n\n - `store`: The metrics store containing the counter\n - `counter_name`: The name of the counter to record a value for\n - `labels`: A dictionary of labels\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = insert_record(\n   store,\n   &quot;http_request_failures&quot;,\n   labels,\n )\n \nSynonyms:\nthemis/counter.create_record\nthemis/counter create_record","url":"themis/counter.html#create_record"},{"doc":"themis/counter","title":"increment_record","content":"pub fn increment_record(\n  store store: Store,\n  counter_name name_string: String,\n  labels labels_dict: Dict(String, String),\n) -&gt; Result(Store, StoreError)\n Increments a counter record with the given labels by 1.\n\n ## Arguments\n\n - `store`: The metrics store containing the counter\n - `counter_name`: The name of the counter to record a value for\n - `labels`: A dictionary of labels\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = increment_record(\n   store,\n   &quot;http_request_failures&quot;,\n   labels,\n )\n \nSynonyms:\nthemis/counter.increment_record\nthemis/counter increment_record","url":"themis/counter.html#increment_record"},{"doc":"themis/counter","title":"increment_record_by","content":"pub fn increment_record_by(\n  store store: Store,\n  counter_name name_string: String,\n  labels labels_dict: Dict(String, String),\n  by by: Number,\n) -&gt; Result(Store, StoreError)\n Increments a counter record with the given labels by a specified value.\n\n ## Arguments\n\n - `store`: The metrics store containing the counter\n - `counter_name`: The name of the counter to record a value for\n - `labels`: A dictionary of labels\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = increment_record(\n   store,\n   &quot;http_request_failures&quot;,\n   labels,\n   number.int(12),\n )\n \nSynonyms:\nthemis/counter.increment_record_by\nthemis/counter increment_record_by","url":"themis/counter.html#increment_record_by"},{"doc":"themis/counter","title":"register","content":"pub fn register(\n  store store: Store,\n  name name_string: String,\n  description description: String,\n) -&gt; Result(Store, StoreError)\n Registers a new counter metric to the store.\n\n ## Arguments\n\n - `store`: The metrics store to add the counter to\n - `name`: The name of the counter metric (must be a valid Prometheus metric name)\n - `description`: A human-readable description of what the counter measures\n\n ## Examples\n\n \n let assert Ok(store) = register(\n   store,\n   &quot;http_request_failures&quot;,\n   &quot;Count of HTTP request failures&quot;,\n )\n \nSynonyms:\nthemis/counter.register\nthemis/counter register","url":"themis/counter.html#register"},{"doc":"themis/counter","title":"unregister","content":"pub fn unregister(\n  store store: Store,\n  counter_name name_string: String,\n) -&gt; Result(Store, StoreError)\n Removes a counter metric and all its recorded values from the store.\n\n ## Arguments\n\n - `store`: The metrics store containing the counter\n - `counter_name`: The name of the counter to delete\n\n ## Examples\n\n \n let assert Ok(store) = unregister(store, &quot;http_request_failures&quot;)\n \nSynonyms:\nthemis/counter.unregister\nthemis/counter unregister","url":"themis/counter.html#unregister"},{"doc":"themis/counter","title":"themis/counter","content":"","url":"themis/counter.html"},{"doc":"themis/gauge","title":"insert_record","content":"pub fn insert_record(\n  store store: Store,\n  gauge_name name_string: String,\n  labels labels_dict: Dict(String, String),\n  value value: Number,\n) -&gt; Result(Store, StoreError)\n Records a value for a gauge metric with the given labels.\n\n ## Arguments\n\n - `store`: The metrics store containing the gauge\n - `gauge_name`: The name of the gauge to record a value for\n - `labels`: A dictionary of labels\n - `value`: The numeric value to record\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = insert_gauge_record(\n   store,\n   &quot;process_cpu_seconds_total&quot;,\n   labels,\n   int(42),\n )\n \nSynonyms:\nthemis/gauge.insert_record\nthemis/gauge insert_record","url":"themis/gauge.html#insert_record"},{"doc":"themis/gauge","title":"register","content":"pub fn register(\n  store store: Store,\n  name name_string: String,\n  description description: String,\n) -&gt; Result(Store, StoreError)\n Registers a new gauge metric to the store.\n\n ## Arguments\n\n - `store`: The metrics store to add the gauge to\n - `name`: The name of the gauge metric (must be a valid Prometheus metric name)\n - `description`: A human-readable description of what the gauge measures\n\n ## Examples\n\n \n let assert Ok(store) = register(\n   store,\n   &quot;process_cpu_seconds_total&quot;,\n   &quot;Total user and system CPU time spent in seconds&quot;,\n )\n \nSynonyms:\nthemis/gauge.register\nthemis/gauge register","url":"themis/gauge.html#register"},{"doc":"themis/gauge","title":"unregister","content":"pub fn unregister(\n  store store: Store,\n  gauge_name name_string: String,\n) -&gt; Result(Store, StoreError)\n Removes a gauge metric and all its recorded values from the store.\n\n ## Arguments\n\n - `store`: The metrics store containing the gauge\n - `gauge_name`: The name of the gauge to delete\n\n ## Examples\n\n \n let assert Ok(store) = unregister(store, &quot;process_cpu_seconds_total&quot;)\n \nSynonyms:\nthemis/gauge.unregister\nthemis/gauge unregister","url":"themis/gauge.html#unregister"},{"doc":"themis/gauge","title":"themis/gauge","content":"","url":"themis/gauge.html"},{"doc":"themis/histogram","title":"create_record","content":"pub fn create_record(\n  store store: Store,\n  histogram_name name_string: String,\n  labels labels_dict: Dict(String, String),\n  bucket_thresholds thresholds: Set(Number),\n) -&gt; Result(Store, StoreError)\n\nSynonyms:\nthemis/histogram.create_record\nthemis/histogram create_record","url":"themis/histogram.html#create_record"},{"doc":"themis/histogram","title":"measure","content":"pub fn measure(\n  store store: Store,\n  histogram_name name_string: String,\n  labels labels_dict: Dict(String, String),\n  measurement value: Number,\n) -&gt; Result(Store, StoreError)\n\nSynonyms:\nthemis/histogram.measure\nthemis/histogram measure","url":"themis/histogram.html#measure"},{"doc":"themis/histogram","title":"register","content":"pub fn register(\n  store store: Store,\n  name name_string: String,\n  description description: String,\n) -&gt; Result(Store, StoreError)\n\nSynonyms:\nthemis/histogram.register\nthemis/histogram register","url":"themis/histogram.html#register"},{"doc":"themis/histogram","title":"unregister","content":"pub fn unregister(\n  store store: Store,\n  histogram_name name_string: String,\n) -&gt; Result(Store, StoreError)\n\nSynonyms:\nthemis/histogram.unregister\nthemis/histogram unregister","url":"themis/histogram.html#unregister"},{"doc":"themis/histogram","title":"themis/histogram","content":"","url":"themis/histogram.html"}]);